@@ -6,16 +6,15 @@
 #ifndef _BIRD_CONFIG_H_
 #define _BIRD_CONFIG_H_
 
-#define XSTR2(X) #X
-#define XSTR1(X) XSTR2(X)
-
 /* BIRD version */
-#ifdef GIT_LABEL
-#define BIRD_VERSION XSTR1(GIT_LABEL)
-#else
-#define BIRD_VERSION "2.16.2"
+#ifndef BIRD_VERSION
+#error "BIRD_VERSION not defined"
 #endif
 
+/* ... is a string literal at least of 4 characters */
+_Static_assert(sizeof(BIRD_VERSION) >= 4, BIRD_VERSION);
+_Static_assert(sizeof(BIRD_VERSION "") == sizeof(BIRD_VERSION), BIRD_VERSION);
+
 /* Include parameters determined by configure script */
 #include "sysdep/autoconf.h"
 
